Feature of the Week
===================

.. toctree::
    :hidden:
    :maxdepth: 1

    fotw-000-data-access
    fotw-001-images


Welcome to the **Daft** Feature of the Week tutorials!

The tutorials in this section showcase core Daft features and how to use them.


Table of Contents
-----------------

The Daft User Guide is laid out as follows:

:doc:`#000 - Data Access <fotw-000-data-access>`
************************************************

A tutorial on the canonical ways of accessing data with Daft.

:doc:`#001 - Data Access <fotw-001-images>`
*******************************************

A tutorial on working with images in Daft.
